CNTabBarMinimizeBehavior enum

Controls when the iOS 26+ tab bar minimizes while scrolling.

Maps to UITabBarController.TabBarMinimizeBehavior. On iOS < 26 every value is treated as never (no-op).

Inheritance
Available extensions

Values

never → const CNTabBarMinimizeBehavior

The tab bar never minimizes on scroll (default).

onScrollDown → const CNTabBarMinimizeBehavior

Minimize when the user scrolls down.

onScrollUp → const CNTabBarMinimizeBehavior

Minimize when the user scrolls up.

automatic → const CNTabBarMinimizeBehavior

Let the system decide based on context.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CNTabBarMinimizeBehavior>
A constant List of the values in this enum, in order of their declaration.