cupertino_native library

Classes

CNButton
A Cupertino-native push button.
CNGlassView
A native iOS liquid-glass surface rendered as a platform view.
CNIcon
A platform-rendered SF Symbol icon.
CNPopupMenuButton
A Cupertino-native popup menu button.
CNPopupMenuDivider
A visual divider between popup menu items.
CNPopupMenuEntry
Base type for entries in a CNPopupMenuButton menu.
CNPopupMenuItem
A selectable item in a popup menu.
CNSegmentedControl
A Cupertino-native segmented control.
CNSlider
A Cupertino-native slider rendered by the host platform.
CNSliderController
Controller for a CNSlider allowing imperative changes to the native NSSlider/UISlider instance.
CNSwitch
A Cupertino-native switch rendered by the host platform.
CNSwitchController
Controller for a CNSwitch that allows imperative updates from Dart to the underlying native UISwitch/NSSwitch instance.
CNSymbol
Describes an SF Symbol to render natively.
CNTabBar
A Cupertino-native tab bar. Uses native UITabBar/NSTabView style visuals.
CNTabBarItem
Immutable data describing a single tab bar item.
CupertinoNative
Top-level facade for simple plugin interactions.
CupertinoNativePlatform
The platform interface that platform implementations of this plugin must extend.
MethodChannelCupertinoNative
An implementation of CupertinoNativePlatform that uses method channels.

Enums

CNButtonStyle
Visual styles for CNButton and related controls.
CNSymbolRenderingMode
Rendering modes for SF Symbols.
CNTabBarMinimizeBehavior
Controls when the iOS 26+ tab bar minimizes while scrolling.